@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of notes in a scale
 
-our $VERSION = '0.02';
+our $VERSION = '0.0201';
 
 use Carp;
 use Moo;
@@ -96,7 +96,7 @@ Music::ScaleNote - Manipulate the position of notes in a scale
 
 =head1 VERSION
 
-version 0.02
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -104,6 +104,7 @@ version 0.02
   my $msn = Music::ScaleNote->new(
     scale_note => 'C',
     scale_name => 'pminor',
+    verbose    => 1,
   );
   my $note = $msn->get_offset(
     note_name   => 'C4',
@@ -116,17 +117,27 @@ version 0.02
 
 A C<Music::ScaleNote> object manipulates the position of notes in a given scale.
 
+Given a scale, a starting note, a scale note, and a scale position offset, this
+module computes the new note.
+
+So for scale C<C D# F G A#> (C pentatonic minor), note C<C4>, and offset C<1>
+(move one note to the right), this module will return C<D#4>.
+
+For offset C<-1>, C<A#3> is returned.
+
 =head1 ATTRIBUTES
 
 =head2 scale_note
 
-This is the name of the note that starts the given B<scale_name>.
+This is the name of the note that starts the given scale.
 
 Default: C
 
 =head2 scale_name
 
-See L<Music::Scales/SCALES> for the possible names.
+This is the name of the scale to use.
+
+Please see L<Music::Scales/SCALES> for the possible names.
 
 Default: major
 
